@@ -1,4 +1,4 @@
-#     Copyright 2014, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2021, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Python tests originally created or extracted from other peoples work. The
 #     parts were too small to be protected.
@@ -15,5 +15,14 @@
 #     See the License for the specific language governing permissions and
 #     limitations under the License.
 #
-print ('Importing unicode BOM file:')
-import unicode_bom
+""" Program that imports a BOM using module.
+
+"""
+
+from __future__ import print_function
+
+import unicode_bom  # pylint: disable=unused-import
+
+print("Importing unicode BOM file:")
+
+print("OK.")
